@@ -1,6 +1,6 @@
-# ClamTk, copyright (C) 2004-2015 Dave M
+# ClamTk, copyright (C) 2004-2016 Dave M
 #
-# This file is part of ClamTk (http://code.google.com/p/clamtk/).
+# This file is part of ClamTk (https://github.com/dave-theunsub/clamtk/wiki).
 #
 # ClamTk is free software; you can redistribute it and/or modify it
 # under the terms of either:
@@ -188,6 +188,10 @@ sub filter {
     # Try to avoid scanning emails...
     $directive .= ' --scan-mail=no';
 
+    # I didn't know we had to explicitly state this.
+    # https://github.com/dave-theunsub/clamtk/issues/59
+    $directive .= ' --scan-archive=yes';
+
     # By default, we ignore .gvfs directories.
     # Once we figure out KDE's process, we'll exclude that too.
     #<<<
